@@ -1,5 +1,5 @@
 # Application version
-ver = '0.0.14'
+ver = '0.1.5'
 
 # Default paths to Mercurial and Git
 hg_cmd = 'hg'
@@ -59,5 +59,7 @@ AOS_SDK_PATH = 'AOS_SDK_PATH'
 OS_PATH = 'os_path'
 OS_NAME = 'AliOS-Things'
 PATH_TYPE = 'path_type'
-COMPONENTS = 'COMPONENTS'
 AOS_COMPONENT_BASE_URL = 'https://github.com/AliOS-Things'
+CUBE_MAKEFILE = 'cube.mk'
+CUBE_MODIFY = 'cube_modify'
+REMOTE_PATH = 'remote'
