@@ -72,8 +72,7 @@ class Git(object):
             rmtree_readonly(os.path.join('.git', 'logs'))
 
     def clone(url, name=None, depth=None, protocol=None):
-        popen([git_cmd, 'clone', formaturl(url, protocol), name] + (['--depth', depth] if depth else []) + (
-        ['-v'] if very_verbose else ([] if verbose else ['-q'])))
+        popen([git_cmd, 'clone', formaturl(url, protocol), name] + (['--depth', depth] if depth else []) + ['-v'])
 
     def add(dest):
         info("Adding reference " + dest)
@@ -353,9 +352,10 @@ class Repo(object):
             repo.name = os.path.basename(path or m_repo_url.group(2)[:-4])
             if repo.name == OS_NAME:
                 repo.path = os.path.abspath(os.path.join(Global().get_path(), repo.name))
-                Global().set_cfg(AOS_SDK_PATH, repo.path)
+                Global().set_cfg(AOS_SDK_PATH, repo.path.replace(os.path.sep, '/'))
             else:
-                repo.path = os.path.abspath(path or os.path.join(os.getcwd(), repo.name))
+                pd = Program(os.getcwd())
+                repo.path = os.path.abspath(path or os.path.join(pd.get_cfg(REMOTE_PATH), repo.name))
             repo.url = formaturl(m_repo_url.group(1))
             repo.rev = m_repo_url.group(3)
             if repo.rev and repo.rev != 'master' and not re.match(r'^([a-fA-F0-9]{6,40})$', repo.rev):
